==> uke-admin-web-scaffold-1.2.0-rc8.tgz: package/plugins/dash-board.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React from 'react';
import PropTypes from 'prop-types';
import { TipPanel } from '../ui-refs';
var desc = "const DashBoard = () => {\n  return (\n    <div>Your dashboard</div>\n  )\n}\n<ManagerAPP DashBoard={DashBoard}/>\n";
var DashBoard = /** @class */ (function (_super) {
    __extends(DashBoard, _super);
    function DashBoard(props) {
        var _this = _super.call(this, props) || this;
        _this.state = {};
        return _this;
    }
    DashBoard.prototype.render = function () {
        var _a = this.props, loadPlugin = _a.loadPlugin, CustomerComponent = _a.CustomerComponent, other = __rest(_a, ["loadPlugin", "CustomerComponent"]);
        return CustomerComponent ? loadPlugin(CustomerComponent, other) : (React.createElement("div", { className: "card-content" },
            React.createElement(TipPanel, { title: "DashBoard \u4F7F\u7528\u8BF4\u660E", texts: [
                    '当所有页面关闭后，会出现这个页面',
                    '主要作用为展示页面数据，并且不会有空白的页面出现',
                    '在最顶层传入 DashBoard 即可，以下为代码示例',
                    (React.createElement("pre", { key: "desc" }, desc))
                ] })));
    };
    DashBoard.propTypes = {
        CustomerComponent: PropTypes.any,
        loadPlugin: PropTypes.func,
    };
    return DashBoard;
}(React.PureComponent));
export default DashBoard;

==> uke-admin-web-scaffold-1.2.4.tgz: package/plugins/dash-board.js <==
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React from 'react';
import PropTypes from 'prop-types';
import { Alert } from '../ui-refs';
var desc = "const DashBoard = () => {\n  return (\n    <div>Your dashboard</div>\n  )\n}\n<ManagerAPP DashBoard={DashBoard}/>\n";
var DashBoard = /** @class */ (function (_super) {
    __extends(DashBoard, _super);
    function DashBoard(props) {
        var _this = _super.call(this, props) || this;
        _this.state = {};
        return _this;
    }
    DashBoard.prototype.render = function () {
        var _a = this.props, loadPlugin = _a.loadPlugin, CustomerComponent = _a.CustomerComponent, other = __rest(_a, ["loadPlugin", "CustomerComponent"]);
        return CustomerComponent ? loadPlugin(CustomerComponent, other) : (React.createElement("div", { className: "card-content" },
            React.createElement(Alert, { title: "DashBoard \u4F7F\u7528\u8BF4\u660E", texts: [
                    '当所有页面关闭后，会出现这个页面',
                    '主要作用为展示页面数据，并且不会有空白的页面出现',
                    '在最顶层传入 DashBoard 即可，以下为代码示例',
                    (React.createElement("pre", { key: "desc" }, desc))
                ] })));
    };
    DashBoard.propTypes = {
        CustomerComponent: PropTypes.any,
        loadPlugin: PropTypes.func,
    };
    return DashBoard;
}(React.PureComponent));
export default DashBoard;
